#!/usr/bin/python3
from pathlib import Path
from pkg_resources import parse_requirements, parse_version
from sys import argv, path

path.insert(0, "/usr/lib/rpm")

import pythondistdeps

# Monkey-patch to work around delayed import in pythondistdeps, without which
# RpmVersion and therefore convert will not work:
pythondistdeps.parse_version = parse_version

deps = []
for path in map(Path, argv[1:]):
    with path.open() as reqfile:
        deps.extend(parse_requirements(reqfile))

# Based on /usr/lib/rpm/pythondistdeps.py, as of python3-rpm-generators-11-11,
# with conditonals hard-coded:

py_deps = {}
for dep in deps:
    extras_suffixes = [""]
    if dep.extras:
        extras_suffixes += [f"[{e}]" for e in dep.extras]
    for extras_suffix in extras_suffixes:
        dep_normalized_name = pythondistdeps.normalize_name(dep.project_name)
        pyver_major = 3
        name = (
            f"python{pyver_major}dist({dep_normalized_name}{extras_suffix})"
        )
        for spec in dep.specs:
            if name not in py_deps:
                py_deps[name] = []
            if spec not in py_deps[name]:
                py_deps[name].append(spec)
        if not dep.specs:
            py_deps[name] = []

for name in sorted(py_deps.keys()):
    if py_deps[name]:
        spec_list = []
        for spec in py_deps[name]:
            spec_list.append(pythondistdeps.convert(name, spec[0], spec[1]))
        if len(spec_list) == 1:
            print(spec_list[0])
        else:
            print("({})".format(" with ".join(sorted(spec_list))))
    else:
        print(name)
